
from __future__ import print_function, division
from io import open

from sklearn.feature_extraction.text import CountVectorizer
from sklearn.linear_model import Perceptron 
from sklearn.pipeline import Pipeline
from sklearn.feature_selection import SelectKBest

from sklearn.metrics import accuracy_score
from sklearn.cross_validation import train_test_split

from lecture2 import NewPerceptron2

# This function reads the corpus, returns a list of documents, and a list
# of their corresponding polarity labels. 
def read_corpus(corpus_file):
    X = []
    Y = []
    with open(corpus_file, encoding='utf-8') as f:
        for line in f:
            tokens = line.strip().split()
            X.append(tokens[3:])
            Y.append(tokens[1])
    return X, Y

if __name__ == '__main__':
    
    # read all the documents
    X, Y = read_corpus('all_sentiment_shuffled.txt')
    
    # split into training and test parts
    Xtrain, Xtest, Ytrain, Ytest = train_test_split(X, Y, train_size=0.8,
                                                    random_state=0)

    classifier = Pipeline( [('vec', CountVectorizer(preprocessor = lambda x: x,
                                                    tokenizer = lambda x: x)),
                            ('fs', SelectKBest(k=5000)),
                            ('cls', NewPerceptron2(n_iter=10))] )

    import time
    t0 = time.time()
    classifier.fit(Xtrain, Ytrain)
    t1 = time.time()
    print('Training time:', t1-t0, 'seconds.')
    
    Yguess = classifier.predict(Xtest)

    print(accuracy_score(Ytest, Yguess))

